@@ -1,4 +1,5 @@
 from javaman.connexio import JManCon
+import requests
 
 
 class Pobles:
@@ -22,7 +23,13 @@ class Pobles:
         return res.json()
 
     def troba(self, provincia_id: int, poble: str):
-        tmp_url = self._url_pobles + '?poble_nom=' + poble + '&provincia_id=' + str(provincia_id)
+        result = None
+        tmp_poble = requests.utils.requote_uri(poble)
+        tmp_url = self._url_pobles + '?poble_nom=' + tmp_poble + '&provincia_id=' + str(provincia_id)
         response = self._con.get(url=tmp_url)
         if response.status_code == 200:
-            return response.json()
+            try:
+                result = response.json()
+            except Exception:
+                result = None
+        return result
