@@ -37,6 +37,94 @@ join TERCERS t on r.TERCER_ID = t.ID
 """
 
 sync_comanda = """
+select
+    c.EMPRESA_ID, 
+    c.ID COMANDA_ID,
+    c.NUMERO_COMANDA,
+    c.REFERENCIA,
+    cd.TERCER_ID CLIENT_ID,
+    cd.REPARTIDOR_ID,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_ter.NOM_LLARG_I_COMERCIAL ELSE c_cli.TERCER END NOM_CLIENT,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_carrer.CARRER ELSE c_cli.ADRECA END ADRECA,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_adr.CPOSTAL ELSE c_cli.CPOSTAL END CPOSTAL,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_poble.POBLE ELSE c_cli_poble.POBLE END POBLE,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_comu.PAIS_CODI ELSE c_cli_comu.PAIS_CODI END CODI_PAIS,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.TELEFON END TELEFON,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.EMAIL END MAIL,
+    cd.PES_NET, cd.PES_BRUT
+
+from comandes c
+join comandes_distribucio cd on c.ID = cd.COMANDA_ID
+join adreces_distribucio cd_adr on cd.ADRECA_DISTRIBUCIO_ID = cd_adr.ID
+join carrers cd_carrer on cd_adr.CARRER_ID = cd_carrer.ID
+join pobles cd_poble on cd_adr.POBLE_ID = cd_poble.ID
+join comarques cd_coma on cd_poble.COMARCA_ID = cd_coma.ID
+join provincies cd_prov on cd_coma.PROVINCIA_ID = cd_prov.ID
+join comunitats cd_comu on cd_prov.COMUNITAT_ID = cd_comu.ID
+
+join tercers cd_ter on cd.TERCER_ID = cd_ter.ID
+join clients cd_cli on cd_ter.ID = cd_cli.TERCER_ID and c.EMPRESA_ID = cd_cli.EMPRESA_ID    
+left join comandes_client c_cli on c.ID = c_cli.COMANDA_ID
+left join pobles c_cli_poble on c_cli.POBLE_ID = c_cli_poble.ID
+left join comarques c_cli_coma on c_cli_poble.COMARCA_ID = c_cli_coma.ID
+left join provincies c_cli_prov on c_cli_coma.PROVINCIA_ID = c_cli_prov.ID
+left join comunitats c_cli_comu on c_cli_prov.COMUNITAT_ID = c_cli_comu.ID
+where c.ID = ?
+"""
+
+sync_comanda_linies = """
+select cl_atr.ID ATRIBUT_ID
+     , sum(cl.QUANTITAT) QUANTITAT
+     , min(cl.NUMERO_LINIA) nl
+     , min(cl.DESCRIPCIO)
+     , sum(cl.QUANTITAT) QUANTITAT_PENDENT
+  from comandes c
+  join comandes_linies cl on c.ID = cl.COMANDA_ID
+  join articles_atributs cl_atr on cl.ARTICLE_ATRIBUT_ID = cl_atr.ID
+  join articles cl_art on cl_atr.ARTICLE_ID = cl_art.ID
+  LEFT join select_articles_c_estocs(cl_art.ID, c.DATA_COMANDA) cl_art_stk on cl_art.ID =  cl_art_stk.ARTICLE_ID
+ where cl_art_stk.CONTROL_ESTOCS = 'S' 
+   and c.ID = ?
+   and cl.magatzem_id = ?
+group by cl_atr.id
+HAVING sum(cl.QUANTITAT) > 0
+"""
+
+sync_comandes_pendents = """
+SELECT C.ID, C.NUMERO_COMANDA, C.DATA_COMANDA,C.DATA_INSERCIO,C.REFERENCIA, T.NOM_LLARG_I_COMERCIAL
+  FROM COMANDES C
+  JOIN CLIENTS CL ON C.CLIENT_ID = CL.ID
+  JOIN TERCERS T ON CL.TERCER_ID = T.ID
+  JOIN COMANDES_DISTRIBUCIO CD ON C.ID = CD.COMANDA_ID
+  JOIN COMANDES_LINIES CCL ON CCL.COMANDA_ID = C.ID
+  left join SELECT_COMANDES_ESTATS_MAG(C.ID) CE ON C.ID = CE.COMANDA_ID
+ where C.DATA_INICI IS NULL 
+   AND CE.MAG_PENDENT_SERVIR = 'S' 
+   AND C.DATA_ANULACIO IS NULL
+   AND CCL.MAGATZEM_ID = ?
+   and CD.REPARTIDOR_ID IS NOT NULL 
+ group by C.ID, C.NUMERO_COMANDA, C.DATA_COMANDA,C.DATA_INSERCIO,C.REFERENCIA, T.NOM_LLARG_I_COMERCIAL;
+"""
+
+sync_magatzems_ordres_pendents = """
+SELECT MO.ID,MO.NUMERO_ORDRE, MO.DATA_INSERCIO, MO.MAGATZEM_ORDRE,MO.MAGATZEM_SORTIDA_ID, MO.MAGATZEM_ENTRADA_ID ,MO.OBSERVACIONS, U.NUMERO_UNITAT
+FROM MAGATZEMS_ORDRES MO
+JOIN MAGATZEMS_ORDRES_DETALL MD ON MO.ID = MD.MAGATZEM_ORDRE_ID
+JOIN UNITATS_LOGISTIQUES U ON U.ID = MD.UNITAT_LOGISTICA_ID
+where MO.DATA_BLOQUEIG IS null
+AND MO.DATA_CONFIRMACIO IS NOT null
+AND MO.DATA_FINALITZACIO IS NULL
+AND MO.MAGATZEM_ENTRADA_ID = ? ;
+"""
+
+sync_moviments_magatzems_pendents = """
+select ma.id,ma.magatzem_origen_id,ma.magatzem_desti_id, ma.data_insercio,ma.data_peticio,ma.observacions
+from moviments_magatzems ma
+where ma.data_lliurament is null
+and ma.magatzem_origen_id = ? ;
+"""
+
+sync_clients_mrest = """
    select cl.id client_id_client,
         cl.codi_client,
         t.nom_llarg nom_client,
